%define tarname	Sphinx

# disable these for bootstrapping nose and sphinx
%bcond_with extras
%bcond_with tests
%bcond_with doc

# some tests fails without internet, disable such
# tests by default
%bcond_with internet

#define         git 20200410
%define         rel 2

Summary:	Python documentation generator
Name:		python-sphinx
Version:	3.4.1
Release:	%mkrel %{?git:-c git%{git}} %{rel}
License:	BSD
Group:		Development/Python
Url:		https://www.sphinx-doc.org
%if 0%{?git}
Source0:        https://github.com/sphinx-doc/sphinx/archive/3.0.x/%{name}-%{version}-git%{git}.tar.gz
%else
Source0:	https://pypi.io/packages/source/S/%{tarname}/%{tarname}-%{version}.tar.gz
%endif

BuildArch:	noarch
BuildRequires:	locales-en
Requires:	python-sphinx-locales = %{version}-%{release}

%description
Sphinx is a tool that facilitates the creation of beautiful
documentation for Python projects from reStructuredText sources. It
was originally created to format the new documentation for Python, but
has since been cleaned up in the hope that it will be useful in many
other projects.

%package -n python3-sphinx
Summary:	Python 3 documentation generator
Group:		Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(alabaster)
BuildRequires:  python3dist(babel)
BuildRequires:  python3dist(docutils)
BuildRequires:  python3dist(imagesize)
BuildRequires:  python3dist(jinja2)
BuildRequires:  python3dist(packaging)
BuildRequires:  python3dist(pygments)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(six)
BuildRequires:  python3dist(snowballstemmer)
BuildRequires:  python3dist(sphinxcontrib-websupport)
BuildRequires:  python3dist(sphinxcontrib-serializinghtml)

%if %{with extras}
BuildRequires:  python3dist(sqlalchemy)
BuildRequires:  python3dist(whoosh)
%endif

%if %{with tests}
BuildRequires:	imagemagick
BuildRequires:  python3-testsuite
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-cov)
BuildRequires:  python3dist(html5lib)
BuildRequires:  python3dist(mock)
BuildRequires:  python3dist(flake8)
BuildRequires:  python3dist(flake8-import-order)
BuildRequires:  python3dist(mypy)
BuildRequires:  python3dist(typed-ast)
BuildRequires:  python3dist(sphinxcontrib-jsmath)
%endif

%if %{with doc}
BuildRequires:  python3dist(sphinxcontrib-applehelp)
BuildRequires:  python3dist(sphinxcontrib-devhelp)
BuildRequires:  python3dist(sphinxcontrib-htmlhelp)
BuildRequires:  python3dist(sphinxcontrib-qthelp)
BuildRequires:  dot
%endif

Requires:	python3-pkg-resources
Requires:	python-sphinx-locales = %{version}-%{release}
Requires:	python3dist(sphinx-rtd-theme)

Provides:	sphinx-build = %{version}-%{release}

%{?python_provide:%python_provide python3-sphinx}
Obsoletes:	python2-sphinx < 1.8.4-3

%description -n python3-sphinx
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.


%package doc
Summary:	Documentation for %{name}
Group:		Documentation
License:	BSD
Requires:	%{name} = %{version}-%{release}

%description doc
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

This package contains documentation in reST and HTML formats.


%package locales
Summary:	Locales for python3-sphinx
Group:		Development/Python
Conflicts:	python2-sphinx < %{version}-%{release}
Conflicts:	python3-sphinx < %{version}-%{release}

%description locales
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

This package contains locales.


%prep
%autosetup -p1 -n %{?git:sphinx-3.0.x}%{?!git:%{tarname}-%{version}}

# Remove tests that use the network
rm -f tests/test_build_linkcheck.py
rm -f tests/test_build.py

%build
%py3_build

%if %{with doc}
export PYTHONPATH=$(pwd)
make -C doc html
make -C doc man
rm -rf doc/_build/html/.buildinfo
mv doc/_build/{html,man}/ .
%endif

%install
%py3_install

# For backwards compatibility. Remove around Mageia 10 (with care)
install -d %{buildroot}%{_libexecdir}/python3-sphinx
for i in sphinx-{apidoc,autogen,build,quickstart}; do
    ln -s %{_bindir}/$i %{buildroot}%{_bindir}/$i-%{python3_version}
    ln -s %{_bindir}/$i %{buildroot}%{_bindir}/$i-3
    ln -s %{_bindir}/$i %{buildroot}%{_libexecdir}/python3-sphinx/$i
done

# Clean up non-python files
rm -f %{buildroot}%{python3_sitelib}/sphinx/locale/.DS_Store
rm -rf %{buildroot}%{python3_sitelib}/sphinx/locale/.tx

%if %{with doc}
# Deliver man pages
install -d %{buildroot}%{_mandir}/man1
install -Dpm644 man/sphinx-*.1 %{buildroot}%{_mandir}/man1/
for f in %{buildroot}%{_mandir}/man1/sphinx-*.1;
do
    cp -p $f $(echo $f | sed -e "s|.1$|-%{python3_version}.1|")
done

# Deliver rst files
rm -rf doc/_build
sed -i 's|python ../sphinx-build.py|/usr/bin/sphinx-build|' doc/Makefile
cp -af doc reST
rm -rf reST/make.bat
%endif

# Move language files to /usr/share;
# patch to support this incorporated in 0.6.6
pushd %{buildroot}%{python3_sitelib}

for lang in `find sphinx/locale -maxdepth 1 -mindepth 1 -type d -not -path '*/\.*' -printf "%f "`;
do
  test $lang == __pycache__ && continue
  install -d %{buildroot}%{_datadir}/sphinx/locale/$lang
  install -d %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.js \
     %{buildroot}%{_datadir}/sphinx/locale/$lang/
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.mo \
    %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/
  rm -rf sphinx/locale/$lang
done
popd

%find_lang sphinx

# Language files; Since these are javascript, it's not immediately obvious to
# find_lang that they need to be marked with a language.
(cd %{buildroot} && find . -name 'sphinx.js') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.js$\):%lang(\2) \1\2\3:' \
  >> sphinx.lang


%if %{with tests}
%check
export LANG=C.UTF-8

# Currently, all linkcheck tests and test_latex_remote_images need internet
# XXX investigate test_gettext_definition_terms test_text_definition_terms
%{__python3} -m pytest \
%if %{without internet}
    -k "not linkcheck and not latex_remote_images and not test_latex_images and not test_gettext_definition_terms and not test_text_definition_terms" \
%endif
;

%endif

%files -n python3-sphinx
%license LICENSE
%doc AUTHORS CHANGES EXAMPLES
%{_bindir}/sphinx-*
%{python3_sitelib}/*
%{_libexecdir}/python3-sphinx/
%if %{with doc}
%{_mandir}/man1/sphinx-*
%endif

%files locales -f sphinx.lang
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale
%dir %{_datadir}/sphinx/locale/*

%if %{with doc}
%files doc
%doc html reST
%endif


%changelog
* Tue Jan 12 2021 daviddavid <daviddavid> 3.4.1-2.mga8
+ Revision: 1671215
- obsoletes python2-sphinx

* Wed Dec 30 2020 kekepower <kekepower> 3.4.1-1.mga8
+ Revision: 1665585
- Update to version 3.4.1

* Sun Dec 20 2020 kekepower <kekepower> 3.4.0-1.mga8
+ Revision: 1661931
- Update to version 3.4.0

* Sat Nov 14 2020 kekepower <kekepower> 3.3.1-1.mga8
+ Revision: 1645839
- Update to version 3.3.1

* Tue Nov 03 2020 kekepower <kekepower> 3.3.0-1.mga8
+ Revision: 1641964
- Update to version 3.3.0

* Sun Nov 01 2020 wally <wally> 3.2.1-2.mga8
+ Revision: 1641431
- provide sphinx-build

* Tue Aug 18 2020 kekepower <kekepower> 3.2.1-1.mga8
+ Revision: 1615319
- Update to version 3.2.1

* Sun Aug 09 2020 kekepower <kekepower> 3.2.0-1.mga8
+ Revision: 1612149
- Update to version 3.2.0

* Sun Jul 05 2020 kekepower <kekepower> 3.1.2-1.mga8
+ Revision: 1602355
- Update to version 3.1.2

* Wed Jun 17 2020 kekepower <kekepower> 3.1.1-1.mga8
+ Revision: 1594055
- Update to version 3.1.1

* Mon Jun 08 2020 kekepower <kekepower> 3.1.0-1.mga8
+ Revision: 1591035
- Update to version 3.1.0

* Wed May 27 2020 kekepower <kekepower> 3.0.4-1.mga8
+ Revision: 1588160
- Update to version 3.0.4

* Sun Apr 26 2020 kekepower <kekepower> 3.0.3-1.mga8
+ Revision: 1572349
- Update to version 3.0.3

* Sun Apr 19 2020 kekepower <kekepower> 3.0.2-1.mga8
+ Revision: 1569881
- Update to version 3.0.2

* Fri Apr 10 2020 kekepower <kekepower> 3.0.1-1.mga8
+ Revision: 1566162
- Update to version 3.0.1

* Fri Apr 10 2020 kekepower <kekepower> 3.0.0-3.mga8
+ Revision: 1566117
- Add upstreap patch to fix crash
  o See https://github.com/sphinx-doc/sphinx/issues/7423

* Fri Apr 10 2020 kekepower <kekepower> 3.0.0-2.mga8
+ Revision: 1566001
- Add upstream patch to fix build failures in parallel builds (-j2 +)

* Sun Apr 05 2020 kekepower <kekepower> 3.0.0-1.mga8
+ Revision: 1564995
- Update to version 3.0.0

* Thu Mar 05 2020 kekepower <kekepower> 2.4.4-1.mga8
+ Revision: 1554081
- Update to version 2.4.4

* Sat Feb 22 2020 kekepower <kekepower> 2.4.3-1.mga8
+ Revision: 1549407
- Update to version 2.4.3

* Sat Feb 22 2020 kekepower <kekepower> 2.4.2-1.mga8
+ Revision: 1549274
- Update to version 2.4.2

* Tue Feb 18 2020 umeabot <umeabot> 2.3.1-2.mga8
+ Revision: 1541487
- Mageia 8 Mass Rebuild

* Sat Dec 28 2019 guillomovitch <guillomovitch> 2.3.1-1.mga8
+ Revision: 1474524
- new version 2.3.1

* Mon Dec 16 2019 kekepower <kekepower> 2.3.0-1.mga8
+ Revision: 1468442
- Update to version 2.3.0

* Sun Dec 15 2019 kekepower <kekepower> 2.2.2-1.mga8
+ Revision: 1467618
- Update to version 2.2.2

* Fri Sep 06 2019 wally <wally> 2.2.0-2.mga8
+ Revision: 1437855
- bootstrap build for python3.8

* Tue Aug 20 2019 wally <wally> 2.2.0-1.mga8
+ Revision: 1430520
- new version 2.2.0

* Mon Jul 15 2019 tv <tv> 2.1.2-1.mga8
+ Revision: 1421666
- Update to 2.1.2 (no more python2 support)

* Mon Apr 29 2019 joequant <joequant> 1.8.4-2.mga7
+ Revision: 1395829
- rebuild to clear error

* Sun Feb 03 2019 kekepower <kekepower> 1.8.4-1.mga7
+ Revision: 1362998
- Rediffed patch1
- Update to version 1.8.4

* Sat Jan 05 2019 wally <wally> 1.8.3-2.mga7
+ Revision: 1349852
- rebuild for python3.7
- enable tests

* Wed Dec 26 2018 kekepower <kekepower> 1.8.3-1.mga7
+ Revision: 1345033
- Update to version 1.8.3

* Sun Nov 11 2018 kekepower <kekepower> 1.8.2-1.mga7
+ Revision: 1329509
- Update to version 1.8.2

* Thu Nov 08 2018 kekepower <kekepower> 1.8.1-3.mga7
+ Revision: 1328979
- No need to be conflicts between py2 and py3 versions of Sphinx
- Fixed file list for the py2 package

* Fri Nov 02 2018 kekepower <kekepower> 1.8.1-2.mga7
+ Revision: 1327557
- Disable tests, enable docs
- BR python[2,3]-pytest
- Enable tests and docs

* Thu Nov 01 2018 kekepower <kekepower> 1.8.1-1.mga7
+ Revision: 1327210
- Update to version 1.8.1
- Disable tests and docs
- Use python_provides
- Use python[2,3]dist instead of pythonegg

* Thu Sep 20 2018 umeabot <umeabot> 1.7.9-2.mga7
+ Revision: 1290162
- Mageia 7 Mass Rebuild

* Fri Sep 07 2018 daviddavid <daviddavid> 1.7.9-1.mga7
+ Revision: 1257640
- new version: 1.7.9

* Tue Aug 28 2018 daviddavid <daviddavid> 1.7.8-1.mga7
+ Revision: 1255350
- new version: 1.7.8

* Sun Mar 25 2018 kekepower <kekepower> 1.7.2-1.mga7
+ Revision: 1212166
- Update to version 1.7.2

* Sat Mar 03 2018 guillomovitch <guillomovitch> 1.7.1-1.mga7
+ Revision: 1206215
- new version 1.7.1

* Mon Feb 26 2018 daviddavid <daviddavid> 1.7.0-5.mga7
+ Revision: 1205328
- reenable doc

* Wed Feb 21 2018 kekepower <kekepower> 1.7.0-4.mga7
+ Revision: 1203887
- Require python2-typing when installing python2-sphinx

* Mon Feb 19 2018 kekepower <kekepower> 1.7.0-3.mga7
+ Revision: 1203196
- Disable building the docs
- Rebuild for new python-packaging
- Exclude python packaging. Fixes installation issue.

* Mon Feb 19 2018 kekepower <kekepower> 1.7.0-1.mga7
+ Revision: 1202998
- Update to version 1.7.0

* Wed Dec 27 2017 wally <wally> 1.6.5-3.mga7
+ Revision: 1185620
- don't exclude requires for sphinxcontrib-websupport as it's really needed

* Wed Dec 27 2017 guillomovitch <guillomovitch> 1.6.5-2.mga7
+ Revision: 1185600
- fix automatic dependencies

* Wed Dec 27 2017 guillomovitch <guillomovitch> 1.6.5-1.mga7
+ Revision: 1185586
- new version 1.6.5

* Sun Nov 26 2017 tv <tv> 1.4.9-3.mga7
+ Revision: 1179373
- sphinx doesn't work w/o sphinx_rtd_theme

* Mon Oct 02 2017 daviddavid <daviddavid> 1.4.9-2.mga7
+ Revision: 1162491
- rename python-sphinx to python2-sphinx
- add BR python(2,3)-pygments to fix build
- remove unneeded hard requires already auto-required

* Thu Aug 03 2017 philippem <philippem> 1.4.9-1.mga7
+ Revision: 1134458
- first python 3.6 build

* Sat Feb 04 2017 philippem <philippem> 1.4.9-1.mga6
+ Revision: 1084838
- update to 1.4.9

* Mon Jul 18 2016 daviddavid <daviddavid> 1.4.1-4.mga6
+ Revision: 1042456
- add upstream patch to fix testsuite failure with new python 3.5.2:
  * https://github.com/sphinx-doc/sphinx/issues/2519

* Tue May 10 2016 philippem <philippem> 1.4.1-3.mga6
+ Revision: 1012063
- move locales in a sub package

* Fri Apr 29 2016 philippem <philippem> 1.4.1-2.mga6
+ Revision: 1007865
- enable tests and docs

* Fri Apr 29 2016 philippem <philippem> 1.4.1-1.mga6
+ Revision: 1007840
- update to 1.4.1 first build without doc

* Sat Feb 20 2016 umeabot <umeabot> 1.3.1-6.mga6
+ Revision: 971139
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 philippem <philippem> 1.3.1-5.mga6
+ Revision: 889355
- rebuild with docs and tests

* Sat Oct 10 2015 tv <tv> 1.3.1-4.mga6
+ Revision: 889009
- rebuild for python 3.5

* Wed Oct 07 2015 philippem <philippem> 1.3.1-3.mga6
+ Revision: 887052
- rebuild for Python 3.5, bootstrap

* Mon Sep 21 2015 philippem <philippem> 1.3.1-2.mga6
+ Revision: 882091
- add symlinks for Python3 version mga#16789

* Thu Aug 20 2015 joequant <joequant> 1.3.1-1.mga6
+ Revision: 866945
- add mock
- add docs
- add requires
- rebuild with docs

* Thu Aug 20 2015 joequant <joequant> 1.3.1-0.2.mga6
+ Revision: 866929
- fix bootstrap issues

* Thu Aug 20 2015 joequant <joequant> 1.3.1-0.1.mga6
+ Revision: 866908
- add 1.3.1 sources
- update to 1.3.1 with bootstrap

* Wed Oct 15 2014 umeabot <umeabot> 1.2.3-4.mga5
+ Revision: 744754
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.3-3.mga5
+ Revision: 729800
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.3-2.mga5
+ Revision: 688346
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 philippem <philippem> 1.2.3-1.mga5
+ Revision: 674394
- update to 1.2.3

* Sat May 31 2014 pterjan <pterjan> 1.2.2-2.mga5
+ Revision: 629025
- Rebuild for new Python

* Sat Mar 08 2014 philippem <philippem> 1.2.2-1.mga5
+ Revision: 601314
- update to 1.2.2

* Tue Oct 22 2013 umeabot <umeabot> 1.1.3-7.mga4
+ Revision: 544172
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.1.3-6.mga4
+ Revision: 499416
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 03 2013 philippem <philippem> 1.1.3-5.mga4
+ Revision: 449988
- Fixes quoting issue in inheritance_diagram.py

* Tue Jul 02 2013 philippem <philippem> 1.1.3-4.mga4
+ Revision: 449676
- add Python 3

* Wed Jan 23 2013 sander85 <sander85> 1.1.3-3.mga3
+ Revision: 391602
- Fix manpage writer in expectation of docutils 0.10 API change (upstream#998)

* Sun Jan 13 2013 umeabot <umeabot> 1.1.3-2.mga3
+ Revision: 379544
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 16 2012 philippem <philippem> 1.1.3-1.mga3
+ Revision: 294491
- New version 1.1.3

* Thu Nov 03 2011 lebedov <lebedov> 1.1.2-1.mga2
+ Revision: 162399
- Update to 1.1.2.

* Tue Oct 11 2011 lebedov <lebedov> 1.1-1.mga2
+ Revision: 153944
- Update to 1.1.

* Sat Sep 24 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 147323
- new version 1.0.8

* Mon Feb 21 2011 ahmad <ahmad> 1.0.7-2.mga1
+ Revision: 55584
- rebuild to make all pythonegg requires/provides lowercase

* Thu Feb 03 2011 ahmad <ahmad> 1.0.7-1.mga1
+ Revision: 46761
- update to 1.0.7

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-7.mga1
+ Revision: 45405
- Enable back as python-nose have been rebuild

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-6.mga1
+ Revision: 45371
- Bump release
- bootstrap for rebuild gainst

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-5.mga1
+ Revision: 45350
- bootstrap because we need to rebuild python-nose
- Rebuild against python 2.7
+ pterjan <pterjan>
- Re-enable tests

* Mon Jan 17 2011 pterjan <pterjan> 1.0.5-4.mga1
+ Revision: 21282
- Enable bootstrap
- Rebuild for python 2.7

* Thu Jan 13 2011 ahmad <ahmad> 1.0.5-3.mga1
+ Revision: 8372
- enable doc and tests

* Thu Jan 13 2011 ahmad <ahmad> 1.0.5-2.mga1
+ Revision: 8357
- disable doc and tests for now
- replace deprecated %%py_requires macro with BR python-devel
- imported package python-sphinx


* Fri Nov 12 2010 Lev Givon <lev@mandriva.org> 1.0.5-1mdv2011.0
+ Revision: 596694
- Update to 1.0.5.

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 1.0.4-3mdv2011.0
+ Revision: 590417
- reenable test and documentation, now that requirement are here

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 1.0.4-2mdv2011.0
+ Revision: 590369
- also fix the documentation generation ( bootstraping problem, since jinja2 requires sphinx too )
- disable test ( as nose requires sphinx, and sphinx requires nose, they cannot be upgraded to 2.7 )
- rebuild for python 2.7

* Fri Sep 17 2010 Lev Givon <lev@mandriva.org> 1.0.4-1mdv2011.0
+ Revision: 579194
- Update to 1.0.4.

* Wed Sep 15 2010 Lev Givon <lev@mandriva.org> 1.0.3-1mdv2011.0
+ Revision: 578780
- Update to 1.0.3.

* Tue Jul 27 2010 Lev Givon <lev@mandriva.org> 0.6.7-1mdv2011.0
+ Revision: 562106
- Update to 0.6.7.
- Update to 0.6.6.

* Thu Mar 11 2010 Lev Givon <lev@mandriva.org> 0.6.5-1mdv2010.1
+ Revision: 518262
- Update to 0.6.5.

* Wed Jan 13 2010 Lev Givon <lev@mandriva.org> 0.6.4-1mdv2010.1
+ Revision: 491048
- Update to 0.6.4.

* Tue Sep 08 2009 Lev Givon <lev@mandriva.org> 0.6.3-1mdv2010.0
+ Revision: 433689
- Update to 0.6.3.
  Build docs as html.

* Wed Aug 05 2009 Paulo Andrade <pcpa@mandriva.com.br> 0.6.2-2mdv2010.0
+ Revision: 409716
- Add sagemath patch to python-sphinx.

* Wed Jun 17 2009 Lev Givon <lev@mandriva.org> 0.6.2-1mdv2010.0
+ Revision: 386763
- Update to 0.6.2.

* Fri May 22 2009 Lev Givon <lev@mandriva.org> 0.6.1-1mdv2010.0
+ Revision: 378621
- Update to 0.6.1.

* Mon May 04 2009 Lev Givon <lev@mandriva.org> 0.5.2-2mdv2010.0
+ Revision: 371821
- Fix requirements.

* Tue Mar 24 2009 Lev Givon <lev@mandriva.org> 0.5.2-1mdv2010.0
+ Revision: 360951
- Update to 0.5.2.
  Change python-setuptools install requirement to python-pkg-resources.

* Sun Jan 04 2009 Jérôme Soyer <saispo@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 324276
- New upstream release

* Sun Dec 28 2008 Funda Wang <fwang@mandriva.org> 0.5-2mdv2009.1
+ Revision: 320265
- rebuild for new python

* Tue Dec 02 2008 Lev Givon <lev@mandriva.org> 0.5-1mdv2009.1
+ Revision: 308946
- Update to 0.5.

* Sun Oct 19 2008 Lev Givon <lev@mandriva.org> 0.4.3-1mdv2009.1
+ Revision: 295422
- Update to 0.4.3.

* Wed Aug 06 2008 Lev Givon <lev@mandriva.org> 0.4.2-2mdv2009.0
+ Revision: 264333
- Add setuptools as an install requirement
  (pkg_resources needed by sphinx-build).

* Wed Aug 06 2008 Lev Givon <lev@mandriva.org> 0.4.2-1mdv2009.0
+ Revision: 264111
- Update to 0.4.2.

* Fri Jul 11 2008 Lev Givon <lev@mandriva.org> 0.4.1-1mdv2009.0
+ Revision: 233844
- Update to 0.4.1.

* Mon Jun 23 2008 Lev Givon <lev@mandriva.org> 0.4-1mdv2009.0
+ Revision: 228282
- Update to 0.4.

* Fri May 30 2008 Lev Givon <lev@mandriva.org> 0.3-1mdv2009.0
+ Revision: 213482
- import python-sphinx


* Thu May 29 2008 Lev Givon <lev@mandriva.org> 0.3-1mdv2008.1
- Package for Mandriva.
